@@ -1,5 +1,5 @@
 #column field types
-from copy import deepcopy
+from copy import deepcopy, copy
 from datetime import datetime
 from datetime import date
 import re
@@ -33,7 +33,7 @@ class BaseValueManager(object):
         return self.value != self.previous_value
 
     def reset_previous_value(self):
-        self.previous_value = deepcopy(self.value)
+        self.previous_value = copy(self.value)
 
     def getval(self):
         return self.value
@@ -394,7 +394,7 @@ class UUID(Column):
         from uuid import UUID as _UUID
         if isinstance(val, _UUID): return val
         if isinstance(val, basestring) and self.re_uuid.match(val):
-                return _UUID(val)
+            return _UUID(val)
         raise ValidationError("{} is not a valid uuid".format(value))
 
     def to_python(self, value):
@@ -513,7 +513,9 @@ class Decimal(Column):
 
 class BaseContainerColumn(Column):
     """
-    Base Container type
+    Base Container type for collection-like columns.
+
+    https://cassandra.apache.org/doc/cql3/CQL.html#collections
     """
 
     def __init__(self, value_type, **kwargs):
@@ -537,6 +539,14 @@ class BaseContainerColumn(Column):
 
         super(BaseContainerColumn, self).__init__(**kwargs)
 
+    def validate(self, value):
+        value = super(BaseContainerColumn, self).validate(value)
+        # It is dangerous to let collections have more than 65535.
+        # See: https://issues.apache.org/jira/browse/CASSANDRA-5428
+        if value is not None and len(value) > 65535:
+            raise ValidationError("Collection can't have more than 65535 elements.")
+        return value
+
     def get_column_def(self):
         """
         Returns a column definition for CQL table definition
@@ -789,6 +799,9 @@ class Map(BaseContainerColumn):
         def keys(self):
             return self.value.keys()
 
+        def items(self):
+            return self.value.items()
+
     def __init__(self, key_type, value_type, default=dict, **kwargs):
         """
         :param key_type: a column class indicating the types of the key
