@@ -94,9 +94,9 @@ def setup(
             try:
                 port = int(host[1])
             except ValueError:
-                raise CQLConnectionError("Can't parse {}".format(''.join(host)))
+                raise CQLConnectionError("Can't parse port as int {}".format(':'.join(host)))
         else:
-            raise CQLConnectionError("Can't parse {}".format(''.join(host)))
+            raise CQLConnectionError("Can't parse host string {}".format(':'.join(host)))
 
         _hosts.append(Host(host[0], port))
 
@@ -157,10 +157,10 @@ class ConnectionPool(object):
         :type conn: connection
         """
 
-        if self._queue.full():
+        try:
+            self._queue.put(conn, block=False)
+        except queue.Full:
             conn.close()
-        else:
-            self._queue.put(conn)
 
     def _create_transport(self, host):
         """
@@ -221,11 +221,11 @@ class ConnectionPool(object):
                 con = self.get()
                 if not con:
                     raise CQLEngineException("Error calling execute without calling setup.")
+                LOG.debug('{} {}'.format(query, repr(params)))
                 cur = con.cursor()
                 cur.execute(query, params, consistency_level=consistency_level)
                 columns = [i[0] for i in cur.description or []]
                 results = [RowResult(r) for r in cur.fetchall()]
-                LOG.debug('{} {}'.format(query, repr(params)))
                 self.put(con)
                 return QueryResult(columns, results)
             except CQLConnectionError as ex:
