@@ -179,10 +179,9 @@ class ColumnDescriptor(object):
         :param instance: the model instance
         :type instance: Model
         """
-
-        if instance:
+        try:
             return instance._values[self.column.column_name].getval()
-        else:
+        except AttributeError as e:
             return self.query_evaluator
 
     def __set__(self, instance, value):
@@ -222,6 +221,8 @@ class BaseModel(object):
     # custom timestamps, see USING TIMESTAMP X
     timestamp = TimestampDescriptor()
 
+    # _len is lazily created by __len__
+
     # table names will be generated automatically from it's model
     # however, you can also define them manually here
     __table_name__ = None
@@ -446,7 +447,11 @@ class BaseModel(object):
 
     def __len__(self):
         """ Returns the number of columns defined on that model. """
-        return len(self._columns.keys())
+        try:
+            return self._len
+        except:
+            self._len = len(self._columns.keys())
+            return self._len
 
     def keys(self):
         """ Returns list of column's IDs. """
@@ -644,9 +649,12 @@ class ModelMetaClass(type):
 
         has_partition_keys = any(v.partition_key for (k, v) in column_definitions)
 
-        #TODO: check that the defined columns don't conflict with any of the Model API's existing attributes/methods
         #transform column definitions
         for k, v in column_definitions:
+            # don't allow a column with the same name as a built-in attribute or method
+            if k in BaseModel.__dict__:
+                raise ModelDefinitionException("column '{}' conflicts with built-in attribute/method".format(k))
+
             # counter column primary keys are not allowed
             if (v.primary_key or v.partition_key) and isinstance(v, (columns.Counter, columns.BaseContainerColumn)):
                 raise ModelDefinitionException('counter columns and container columns cannot be used as primary keys')
@@ -656,7 +664,7 @@ class ModelMetaClass(type):
             if not has_partition_keys and v.primary_key:
                 v.partition_key = True
                 has_partition_keys = True
-            _transform_column(k,v)
+            _transform_column(k, v)
 
         partition_keys = OrderedDict(k for k in primary_keys.items() if k[1].partition_key)
         clustering_keys = OrderedDict(k for k in primary_keys.items() if not k[1].partition_key)
