@@ -169,6 +169,8 @@ class SetUpdateClause(ContainerUpdateClause):
     def __unicode__(self):
         qs = []
         ctx_id = self.context_id
+        if self.previous is None and not (self._assignments or self._additions or self._removals):
+            qs += ['"{}" = :{}'.format(self.field, ctx_id)]
         if self._assignments:
             qs += ['"{}" = :{}'.format(self.field, ctx_id)]
             ctx_id += 1
@@ -198,11 +200,15 @@ class SetUpdateClause(ContainerUpdateClause):
 
     def get_context_size(self):
         if not self._analyzed: self._analyze()
+        if self.previous is None and not (self._assignments or self._additions or self._removals):
+            return 1
         return int(bool(self._assignments)) + int(bool(self._additions)) + int(bool(self._removals))
 
     def update_context(self, ctx):
         if not self._analyzed: self._analyze()
         ctx_id = self.context_id
+        if self.previous is None and not (self._assignments or self._additions or self._removals):
+            ctx[str(ctx_id)] = self._to_database({})
         if self._assignments:
             ctx[str(ctx_id)] = self._to_database(self._assignments)
             ctx_id += 1
@@ -314,36 +320,46 @@ class MapUpdateClause(ContainerUpdateClause):
     def __init__(self, field, value, operation=None, previous=None, column=None):
         super(MapUpdateClause, self).__init__(field, value, operation, previous, column=column)
         self._updates = None
-        self.previous = self.previous or {}
 
     def _analyze(self):
         if self._operation == "update":
             self._updates = self.value.keys()
         else:
-            self._updates = sorted([k for k, v in self.value.items() if v != self.previous.get(k)]) or None
+            if self.previous is None:
+                self._updates = sorted([k for k, v in self.value.items()])
+            else:
+                self._updates = sorted([k for k, v in self.value.items() if v != self.previous.get(k)]) or None
         self._analyzed = True
 
     def get_context_size(self):
         if not self._analyzed: self._analyze()
+        if self.previous is None and not self._updates:
+            return 1
         return len(self._updates or []) * 2
 
     def update_context(self, ctx):
         if not self._analyzed: self._analyze()
         ctx_id = self.context_id
-        for key in self._updates or []:
-            val = self.value.get(key)
-            ctx[str(ctx_id)] = self._column.key_col.to_database(key) if self._column else key
-            ctx[str(ctx_id + 1)] = self._column.value_col.to_database(val) if self._column else val
-            ctx_id += 2
+        if self.previous is None and not self._updates:
+            ctx[str(ctx_id)] = {}
+        else:
+            for key in self._updates or []:
+                val = self.value.get(key)
+                ctx[str(ctx_id)] = self._column.key_col.to_database(key) if self._column else key
+                ctx[str(ctx_id + 1)] = self._column.value_col.to_database(val) if self._column else val
+                ctx_id += 2
 
     def __unicode__(self):
         if not self._analyzed: self._analyze()
         qs = []
 
         ctx_id = self.context_id
-        for _ in self._updates or []:
-            qs += ['"{}"[:{}] = :{}'.format(self.field, ctx_id, ctx_id + 1)]
-            ctx_id += 2
+        if self.previous is None and not self._updates:
+            qs += ['"int_map" = :1']
+        else:
+            for _ in self._updates or []:
+                qs += ['"{}"[:{}] = :{}'.format(self.field, ctx_id, ctx_id + 1)]
+                ctx_id += 2
 
         return ', '.join(qs)
 
