@@ -9,12 +9,14 @@ from cqlengine.tests.base import BaseCassEngTestCase
 
 
 class TestSetModel(Model):
+
     partition = columns.UUID(primary_key=True, default=uuid4)
     int_set = columns.Set(columns.Integer, required=False)
     text_set = columns.Set(columns.Text, required=False)
 
 
 class JsonTestColumn(columns.Column):
+
     db_type = 'text'
 
     def to_python(self, value):
@@ -65,6 +67,15 @@ class TestSetColumn(BaseCassEngTestCase):
         m = TestSetModel.get(partition=m.partition)
         self.assertNotIn(5, m.int_set)
 
+    def test_blind_deleting_last_item_should_succeed(self):
+        m = TestSetModel.create()
+        m.int_set.add(5)
+        m.save()
+
+        TestSetModel.objects(partition=m.partition).update(int_set=set())
+
+        m = TestSetModel.get(partition=m.partition)
+        self.assertNotIn(5, m.int_set)
 
     def test_empty_set_retrieval(self):
         m = TestSetModel.create()
@@ -92,6 +103,14 @@ class TestSetColumn(BaseCassEngTestCase):
         with self.assertRaises(ValidationError):
             TestSetModel.create(int_set={'string', True}, text_set={1, 3.0})
 
+    def test_element_count_validation(self):
+        """
+        Tests that big collections are detected and raise an exception.
+        """
+        TestSetModel.create(text_set={str(uuid4()) for i in range(65535)})
+        with self.assertRaises(ValidationError):
+            TestSetModel.create(text_set={str(uuid4()) for i in range(65536)})
+
     def test_partial_updates(self):
         """ Tests that partial udpates work as expected """
         m1 = TestSetModel.create(int_set={1, 2, 3, 4})
@@ -182,12 +201,14 @@ class TestSetColumn(BaseCassEngTestCase):
 
 
 class TestListModel(Model):
+
     partition = columns.UUID(primary_key=True, default=uuid4)
     int_list = columns.List(columns.Integer, required=False)
     text_list = columns.List(columns.Text, required=False)
 
 
 class TestListColumn(BaseCassEngTestCase):
+
     @classmethod
     def setUpClass(cls):
         super(TestListColumn, cls).setUpClass()
@@ -232,6 +253,14 @@ class TestListColumn(BaseCassEngTestCase):
         with self.assertRaises(ValidationError):
             TestListModel.create(int_list=['string', True], text_list=[1, 3.0])
 
+    def test_element_count_validation(self):
+        """
+        Tests that big collections are detected and raise an exception.
+        """
+        TestListModel.create(text_list=[str(uuid4()) for i in range(65535)])
+        with self.assertRaises(ValidationError):
+            TestListModel.create(text_list=[str(uuid4()) for i in range(65536)])
+
     def test_partial_updates(self):
         """ Tests that partial udpates work as expected """
         final = range(10)
@@ -341,17 +370,30 @@ class TestListColumn(BaseCassEngTestCase):
         with self.assertRaises(ValidationError):
             TestListModel.create(partition=pkey, int_list=[None])
 
+    def test_blind_list_updates_from_none(self):
+        """ Tests that updates from None work as expected """
+        m = TestListModel.create(int_list=None)
+        expected = [1, 2]
+        m.int_list = expected
+        m.save()
 
+        m2 = TestListModel.get(partition=m.partition)
+        assert m2.int_list == expected
 
+        TestListModel.objects(partition=m.partition).update(int_list=[])
 
+        m3 = TestListModel.get(partition=m.partition)
+        assert m3.int_list == []
 
 class TestMapModel(Model):
+
     partition = columns.UUID(primary_key=True, default=uuid4)
     int_map = columns.Map(columns.Integer, columns.UUID, required=False)
     text_map = columns.Map(columns.Text, columns.DateTime, required=False)
 
 
 class TestMapColumn(BaseCassEngTestCase):
+
     @classmethod
     def setUpClass(cls):
         super(TestMapColumn, cls).setUpClass()
@@ -375,13 +417,11 @@ class TestMapColumn(BaseCassEngTestCase):
         with self.assertRaises(ValidationError):
             TestMapModel.create(int_map={None:1})
 
-
     def test_empty_retrieve(self):
         tmp = TestMapModel.create()
         tmp2 = TestMapModel.get(partition=tmp.partition)
         tmp2.int_map['blah'] = 1
 
-
     def test_remove_last_entry_works(self):
         tmp = TestMapModel.create()
         tmp.text_map["blah"] = datetime.now()
@@ -392,8 +432,6 @@ class TestMapColumn(BaseCassEngTestCase):
         tmp = TestMapModel.get(partition=tmp.partition)
         self.assertNotIn("blah", tmp.int_map)
 
-
-
     def test_io_success(self):
         """ Tests that a basic usage works as expected """
         k1 = uuid4()
@@ -423,6 +461,14 @@ class TestMapColumn(BaseCassEngTestCase):
         with self.assertRaises(ValidationError):
             TestMapModel.create(int_map={'key': 2, uuid4(): 'val'}, text_map={2: 5})
 
+    def test_element_count_validation(self):
+        """
+        Tests that big collections are detected and raise an exception.
+        """
+        TestMapModel.create(text_map={str(uuid4()): i for i in range(65535)})
+        with self.assertRaises(ValidationError):
+            TestMapModel.create(text_map={str(uuid4()): i for i in range(65536)})
+
     def test_partial_updates(self):
         """ Tests that partial udpates work as expected """
         now = datetime.now()
@@ -450,7 +496,6 @@ class TestMapColumn(BaseCassEngTestCase):
         m.int_map = expected
         m.save()
 
-
         m2 = TestMapModel.get(partition=m.partition)
         assert m2.int_map == expected
 
@@ -459,6 +504,21 @@ class TestMapColumn(BaseCassEngTestCase):
         m3 = TestMapModel.get(partition=m.partition)
         assert m3.int_map != expected
 
+    def test_blind_updates_from_none(self):
+        """ Tests that updates from None work as expected """
+        m = TestMapModel.create(int_map=None)
+        expected = {1: uuid4()}
+        m.int_map = expected
+        m.save()
+
+        m2 = TestMapModel.get(partition=m.partition)
+        assert m2.int_map == expected
+
+        TestMapModel.objects(partition=m.partition).update(int_map={})
+
+        m3 = TestMapModel.get(partition=m.partition)
+        assert m3.int_map != expected
+
     def test_updates_to_none(self):
         """ Tests that setting the field to None works as expected """
         m = TestMapModel.create(int_map={1: uuid4()})
@@ -523,11 +583,15 @@ class TestMapColumn(BaseCassEngTestCase):
 #        assert len([s for s in statements if '"TEST" = "TEST" +' in s]) == 1
 #        assert len([s for s in statements if '+ "TEST"' in s]) == 1
 
+
 class TestCamelMapModel(Model):
+
     partition = columns.UUID(primary_key=True, default=uuid4)
     camelMap = columns.Map(columns.Text, columns.Integer, required=False)
 
+
 class TestCamelMapColumn(BaseCassEngTestCase):
+
     @classmethod
     def setUpClass(cls):
         super(TestCamelMapColumn, cls).setUpClass()
@@ -541,4 +605,3 @@ class TestCamelMapColumn(BaseCassEngTestCase):
 
     def test_camelcase_column(self):
         TestCamelMapModel.create(partition=None, camelMap={'blah': 1})
-
